@@ -3,6 +3,7 @@ pub(crate) mod contexts;
 pub(crate) mod cronjobs;
 pub(crate) mod daemonsets;
 pub(crate) mod deployments;
+pub(crate) mod ingress;
 pub(crate) mod jobs;
 pub(crate) mod key_binding;
 pub(crate) mod metrics;
@@ -10,10 +11,13 @@ pub(crate) mod models;
 pub(crate) mod nodes;
 pub(crate) mod ns;
 pub(crate) mod pods;
+pub(crate) mod pvcs;
+pub(crate) mod pvs;
 pub(crate) mod replicasets;
 pub(crate) mod replication_controllers;
 pub(crate) mod roles;
 pub(crate) mod secrets;
+pub(crate) mod serviceaccounts;
 pub(crate) mod statefulsets;
 pub(crate) mod storageclass;
 pub(crate) mod svcs;
@@ -31,6 +35,7 @@ use self::{
   cronjobs::KubeCronJob,
   daemonsets::KubeDaemonSet,
   deployments::KubeDeployment,
+  ingress::KubeIngress,
   jobs::KubeJob,
   key_binding::DEFAULT_KEYBINDING,
   metrics::KubeNodeMetrics,
@@ -38,10 +43,13 @@ use self::{
   nodes::KubeNode,
   ns::KubeNs,
   pods::{KubeContainer, KubePod},
+  pvcs::KubePVC,
+  pvs::KubePV,
   replicasets::KubeReplicaSet,
   replication_controllers::KubeReplicationController,
   roles::{KubeClusterRole, KubeClusterRoleBinding, KubeRole, KubeRoleBinding},
   secrets::KubeSecret,
+  serviceaccounts::KubeSvcAcct,
   statefulsets::KubeStatefulSet,
   storageclass::KubeStorageClass,
   svcs::KubeSvc,
@@ -78,6 +86,10 @@ pub enum ActiveBlock {
   RoleBindings,
   ClusterRoles,
   ClusterRoleBinding,
+  Ingress,
+  Pvc,
+  Pv,
+  ServiceAccounts,
   More,
 }
 
@@ -136,7 +148,11 @@ pub struct Data {
   pub roles: StatefulTable<KubeRole>,
   pub role_bindings: StatefulTable<KubeRoleBinding>,
   pub cluster_roles: StatefulTable<KubeClusterRole>,
-  pub cluster_role_binding: StatefulTable<KubeClusterRoleBinding>,
+  pub cluster_role_bindings: StatefulTable<KubeClusterRoleBinding>,
+  pub ingress: StatefulTable<KubeIngress>,
+  pub pvcs: StatefulTable<KubePVC>,
+  pub pvs: StatefulTable<KubePV>,
+  pub service_accounts: StatefulTable<KubeSvcAcct>,
 }
 
 /// selected data items
@@ -213,7 +229,11 @@ impl Default for Data {
       roles: StatefulTable::new(),
       role_bindings: StatefulTable::new(),
       cluster_roles: StatefulTable::new(),
-      cluster_role_binding: StatefulTable::new(),
+      cluster_role_bindings: StatefulTable::new(),
+      ingress: StatefulTable::new(),
+      pvcs: StatefulTable::new(),
+      pvs: StatefulTable::new(),
+      service_accounts: StatefulTable::new(),
     }
   }
 }
@@ -335,8 +355,8 @@ impl Default for App {
         ("Cron Jobs".into(), ActiveBlock::CronJobs),
         ("Secrets".into(), ActiveBlock::Secrets),
         ("Replication Controllers".into(), ActiveBlock::RplCtrl),
-        // ("Persistent Volume Claims".into(), ActiveBlock::RplCtrl),
-        // ("Persistent Volumes".into(), ActiveBlock::RplCtrl),
+        ("Persistent Volume Claims".into(), ActiveBlock::Pvc),
+        ("Persistent Volumes".into(), ActiveBlock::Pv),
         ("Storage Classes".into(), ActiveBlock::StorageClasses),
         ("Roles".into(), ActiveBlock::Roles),
         ("Role Bindings".into(), ActiveBlock::RoleBindings),
@@ -345,8 +365,8 @@ impl Default for App {
           "Cluster Role Bindings".into(),
           ActiveBlock::ClusterRoleBinding,
         ),
-        // ("Service Accounts".into(), ActiveBlock::RplCtrl),
-        // ("Ingresses".into(), ActiveBlock::RplCtrl),
+        ("Service Accounts".into(), ActiveBlock::ServiceAccounts),
+        ("Ingresses".into(), ActiveBlock::Ingress),
         // ("Network Policies".into(), ActiveBlock::RplCtrl),
       ]),
       show_info_bar: true,
@@ -539,7 +559,11 @@ impl App {
     self.dispatch(IoEvent::GetRoles).await;
     self.dispatch(IoEvent::GetRoleBindings).await;
     self.dispatch(IoEvent::GetClusterRoles).await;
-    self.dispatch(IoEvent::GetClusterRoleBinding).await;
+    self.dispatch(IoEvent::GetClusterRoleBindings).await;
+    self.dispatch(IoEvent::GetIngress).await;
+    self.dispatch(IoEvent::GetPvcs).await;
+    self.dispatch(IoEvent::GetPvs).await;
+    self.dispatch(IoEvent::GetServiceAccounts).await;
     self.dispatch(IoEvent::GetMetrics).await;
   }
 
@@ -591,7 +615,19 @@ impl App {
         self.dispatch(IoEvent::GetClusterRoles).await;
       }
       ActiveBlock::ClusterRoleBinding => {
-        self.dispatch(IoEvent::GetClusterRoleBinding).await;
+        self.dispatch(IoEvent::GetClusterRoleBindings).await;
+      }
+      ActiveBlock::Ingress => {
+        self.dispatch(IoEvent::GetIngress).await;
+      }
+      ActiveBlock::Pvc => {
+        self.dispatch(IoEvent::GetPvcs).await;
+      }
+      ActiveBlock::Pv => {
+        self.dispatch(IoEvent::GetPvs).await;
+      }
+      ActiveBlock::ServiceAccounts => {
+        self.dispatch(IoEvent::GetServiceAccounts).await;
       }
       ActiveBlock::Logs => {
         if !self.is_streaming {
@@ -753,7 +789,14 @@ mod tests {
     assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetClusterRoles);
     assert_eq!(
       sync_io_rx.recv().await.unwrap(),
-      IoEvent::GetClusterRoleBinding
+      IoEvent::GetClusterRoleBindings
+    );
+    assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetIngress);
+    assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetPvcs);
+    assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetPvs);
+    assert_eq!(
+      sync_io_rx.recv().await.unwrap(),
+      IoEvent::GetServiceAccounts
     );
     assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetMetrics);
     assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetNamespaces);
