@@ -6,7 +6,7 @@ use k8s_openapi::{
 use super::{models::KubeResource, utils};
 
 #[derive(Clone, Debug, PartialEq)]
-pub struct KubeRoles {
+pub struct KubeRole {
   pub namespace: String,
   pub name: String,
   pub age: String,
@@ -14,7 +14,7 @@ pub struct KubeRoles {
 }
 
 #[derive(Clone, Debug, PartialEq)]
-pub struct KubeRoleBindings {
+pub struct KubeRoleBinding {
   pub namespace: String,
   pub name: String,
   pub role: String,
@@ -23,7 +23,7 @@ pub struct KubeRoleBindings {
 }
 
 #[derive(Clone, Debug, PartialEq)]
-pub struct KubeClusterRoles {
+pub struct KubeClusterRole {
   pub name: String,
   pub age: String,
   k8s_obj: ClusterRole,
@@ -37,41 +37,45 @@ pub struct KubeClusterRoleBinding {
   k8s_obj: ClusterRoleBinding,
 }
 
-impl KubeResource<Role> for KubeRoles {
-  fn from_api(role: &Role) -> Self {
-    KubeRoles {
+impl From<Role> for KubeRole {
+  fn from(role: Role) -> Self {
+    KubeRole {
       namespace: role.metadata.namespace.clone().unwrap_or_default(),
       name: role.metadata.name.clone().unwrap_or_default(),
       age: utils::to_age(role.metadata.creation_timestamp.as_ref(), Utc::now()),
-      k8s_obj: role.to_owned(),
+      k8s_obj: utils::sanitize_obj(role),
     }
   }
+}
 
+impl KubeResource<Role> for KubeRole {
   fn get_k8s_obj(&self) -> &Role {
     &self.k8s_obj
   }
 }
 
-impl KubeResource<ClusterRole> for KubeClusterRoles {
-  fn from_api(cluster_role: &ClusterRole) -> Self {
-    KubeClusterRoles {
+impl From<ClusterRole> for KubeClusterRole {
+  fn from(cluster_role: ClusterRole) -> Self {
+    KubeClusterRole {
       name: cluster_role.metadata.name.clone().unwrap_or_default(),
       age: utils::to_age(
         cluster_role.metadata.creation_timestamp.as_ref(),
         Utc::now(),
       ),
-      k8s_obj: cluster_role.to_owned(),
+      k8s_obj: utils::sanitize_obj(cluster_role),
     }
   }
+}
 
+impl KubeResource<ClusterRole> for KubeClusterRole {
   fn get_k8s_obj(&self) -> &ClusterRole {
     &self.k8s_obj
   }
 }
 
-impl KubeResource<RoleBinding> for KubeRoleBindings {
-  fn from_api(role_binding: &RoleBinding) -> Self {
-    KubeRoleBindings {
+impl From<RoleBinding> for KubeRoleBinding {
+  fn from(role_binding: RoleBinding) -> Self {
+    KubeRoleBinding {
       namespace: role_binding.metadata.namespace.clone().unwrap_or_default(),
       name: role_binding.metadata.name.clone().unwrap_or_default(),
       role: role_binding.role_ref.name.clone(),
@@ -79,36 +83,28 @@ impl KubeResource<RoleBinding> for KubeRoleBindings {
         role_binding.metadata.creation_timestamp.as_ref(),
         Utc::now(),
       ),
-      k8s_obj: role_binding.to_owned(),
+      k8s_obj: utils::sanitize_obj(role_binding),
     }
   }
-
+}
+impl KubeResource<RoleBinding> for KubeRoleBinding {
   fn get_k8s_obj(&self) -> &RoleBinding {
     &self.k8s_obj
   }
 }
 
-impl KubeResource<ClusterRoleBinding> for KubeClusterRoleBinding {
-  fn from_api(cluster_role_binding: &ClusterRoleBinding) -> Self {
+impl From<ClusterRoleBinding> for KubeClusterRoleBinding {
+  fn from(crb: ClusterRoleBinding) -> Self {
     KubeClusterRoleBinding {
-      name: cluster_role_binding
-        .metadata
-        .name
-        .clone()
-        .unwrap_or_default(),
-      role: format!(
-        "{}/{}",
-        cluster_role_binding.role_ref.kind.clone(),
-        cluster_role_binding.role_ref.name.clone()
-      ),
-      age: utils::to_age(
-        cluster_role_binding.metadata.creation_timestamp.as_ref(),
-        Utc::now(),
-      ),
-      k8s_obj: cluster_role_binding.to_owned(),
+      name: crb.metadata.name.clone().unwrap_or_default(),
+      role: format!("{}/{}", crb.role_ref.kind, crb.role_ref.name),
+      age: utils::to_age(crb.metadata.creation_timestamp.as_ref(), Utc::now()),
+      k8s_obj: utils::sanitize_obj(crb),
     }
   }
+}
 
+impl KubeResource<ClusterRoleBinding> for KubeClusterRoleBinding {
   fn get_k8s_obj(&self) -> &ClusterRoleBinding {
     &self.k8s_obj
   }
@@ -119,19 +115,19 @@ mod tests {
   use k8s_openapi::chrono::Utc;
 
   use crate::app::{
-    roles::{KubeClusterRoleBinding, KubeClusterRoles, KubeRoleBindings, KubeRoles},
+    roles::{KubeClusterRole, KubeClusterRoleBinding, KubeRole, KubeRoleBinding},
     test_utils::{convert_resource_from_file, get_time},
     utils,
   };
 
   #[test]
   fn test_roles_binding_from_rbac_api() {
-    let (roles, roles_list): (Vec<KubeRoles>, Vec<_>) = convert_resource_from_file("roles");
+    let (roles, roles_list): (Vec<KubeRole>, Vec<_>) = convert_resource_from_file("roles");
 
     assert_eq!(roles.len(), 1);
     assert_eq!(
       roles[0],
-      KubeRoles {
+      KubeRole {
         namespace: "default".to_string(),
         name: "kiali-viewer".into(),
         age: utils::to_age(Some(&get_time("2022-06-27T16:33:06Z")), Utc::now()),
@@ -142,13 +138,13 @@ mod tests {
 
   #[test]
   fn test_cluster_roles_from_rbac_api() {
-    let (cluster_roles, cluster_roles_list): (Vec<KubeClusterRoles>, Vec<_>) =
+    let (cluster_roles, cluster_roles_list): (Vec<KubeClusterRole>, Vec<_>) =
       convert_resource_from_file("clusterroles");
 
     assert_eq!(cluster_roles.len(), 1);
     assert_eq!(
       cluster_roles[0],
-      KubeClusterRoles {
+      KubeClusterRole {
         name: "admin".into(),
         age: utils::to_age(Some(&get_time("2021-12-14T11:04:22Z")), Utc::now()),
         k8s_obj: cluster_roles_list[0].clone(),
@@ -158,13 +154,13 @@ mod tests {
 
   #[test]
   fn test_role_binding_from_rbac_api() {
-    let (role_bindings, rolebindings_list): (Vec<KubeRoleBindings>, Vec<_>) =
+    let (role_bindings, rolebindings_list): (Vec<KubeRoleBinding>, Vec<_>) =
       convert_resource_from_file("role_bindings");
 
     assert_eq!(role_bindings.len(), 1);
     assert_eq!(
       role_bindings[0],
-      KubeRoleBindings {
+      KubeRoleBinding {
         namespace: "default".to_string(),
         name: "kiali".into(),
         role: "kiali-viewer".into(),
