@@ -1,3 +1,4 @@
+use base64::{engine::general_purpose, Engine as _};
 use crossterm::event::{MouseEvent, MouseEventKind};
 use kubectl_view_allocations::GroupBy;
 use serde::Serialize;
@@ -128,7 +129,7 @@ where
       // decode each of the key/values in the secret
       for (key_name, encoded_bytes) in secret.data.iter() {
         let decoded_str = match serde_yaml::to_string(encoded_bytes) {
-          Ok(encoded_str) => match base64::decode(encoded_str.trim()) {
+          Ok(encoded_str) => match general_purpose::STANDARD.decode(encoded_str.trim()) {
             Ok(decoded_bytes) => String::from_utf8(decoded_bytes).unwrap(),
             Err(_) => format!("cannot decode value: {}", encoded_str.trim()),
           },
@@ -507,7 +508,7 @@ async fn handle_route_events(key: Key, app: &mut App) {
           }
         }
         ActiveBlock::ClusterRoleBinding => {
-          if let Some(res) = handle_block_action(key, &mut app.data.cluster_role_binding) {
+          if let Some(res) = handle_block_action(key, &mut app.data.cluster_role_bindings) {
             let _ok = handle_describe_decode_or_yaml_action(
               key,
               app,
@@ -521,6 +522,66 @@ async fn handle_route_events(key: Key, app: &mut App) {
             .await;
           }
         }
+        ActiveBlock::Ingress => {
+          if let Some(res) = handle_block_action(key, &mut app.data.ingress) {
+            let _ok = handle_describe_decode_or_yaml_action(
+              key,
+              app,
+              &res,
+              IoCmdEvent::GetDescribe {
+                kind: "ingress".to_owned(),
+                value: res.name.to_owned(),
+                ns: Some(res.namespace.to_owned()),
+              },
+            )
+            .await;
+          }
+        }
+        ActiveBlock::Pvc => {
+          if let Some(res) = handle_block_action(key, &mut app.data.pvcs) {
+            let _ok = handle_describe_decode_or_yaml_action(
+              key,
+              app,
+              &res,
+              IoCmdEvent::GetDescribe {
+                kind: "persistentvolumeclaims".to_owned(),
+                value: res.name.to_owned(),
+                ns: Some(res.namespace.to_owned()),
+              },
+            )
+            .await;
+          }
+        }
+        ActiveBlock::Pv => {
+          if let Some(res) = handle_block_action(key, &mut app.data.pvs) {
+            let _ok = handle_describe_decode_or_yaml_action(
+              key,
+              app,
+              &res,
+              IoCmdEvent::GetDescribe {
+                kind: "persistentvolumes".to_owned(),
+                value: res.name.to_owned(),
+                ns: None,
+              },
+            )
+            .await;
+          }
+        }
+        ActiveBlock::ServiceAccounts => {
+          if let Some(res) = handle_block_action(key, &mut app.data.service_accounts) {
+            let _ok = handle_describe_decode_or_yaml_action(
+              key,
+              app,
+              &res,
+              IoCmdEvent::GetDescribe {
+                kind: "serviceaccounts".to_owned(),
+                value: res.name.to_owned(),
+                ns: Some(res.namespace.to_owned()),
+              },
+            )
+            .await;
+          }
+        }
         ActiveBlock::Contexts | ActiveBlock::Utilization | ActiveBlock::Help => { /* Do nothing */ }
       }
     }
@@ -587,7 +648,11 @@ async fn handle_block_scroll(app: &mut App, up: bool, is_mouse: bool, page: bool
     ActiveBlock::Roles => app.data.roles.handle_scroll(up, page),
     ActiveBlock::RoleBindings => app.data.role_bindings.handle_scroll(up, page),
     ActiveBlock::ClusterRoles => app.data.cluster_roles.handle_scroll(up, page),
-    ActiveBlock::ClusterRoleBinding => app.data.cluster_role_binding.handle_scroll(up, page),
+    ActiveBlock::ClusterRoleBinding => app.data.cluster_role_bindings.handle_scroll(up, page),
+    ActiveBlock::Pvc => app.data.pvcs.handle_scroll(up, page),
+    ActiveBlock::Pv => app.data.pvs.handle_scroll(up, page),
+    ActiveBlock::Ingress => app.data.ingress.handle_scroll(up, page),
+    ActiveBlock::ServiceAccounts => app.data.service_accounts.handle_scroll(up, page),
     ActiveBlock::Contexts => app.data.contexts.handle_scroll(up, page),
     ActiveBlock::Utilization => app.data.metrics.handle_scroll(up, page),
     ActiveBlock::Help => app.help_docs.handle_scroll(up, page),
