@@ -31,7 +31,11 @@ pub enum IoEvent {
   GetRoles,
   GetRoleBindings,
   GetClusterRoles,
-  GetClusterRoleBinding,
+  GetClusterRoleBindings,
+  GetIngress,
+  GetPvcs,
+  GetPvs,
+  GetServiceAccounts,
   GetMetrics,
   RefreshClient,
 }
@@ -171,9 +175,21 @@ impl<'a> Network<'a> {
       IoEvent::GetClusterRoles => {
         self.get_cluster_roles().await;
       }
-      IoEvent::GetClusterRoleBinding => {
+      IoEvent::GetClusterRoleBindings => {
         self.get_cluster_role_binding().await;
       }
+      IoEvent::GetIngress => {
+        self.get_ingress().await;
+      }
+      IoEvent::GetPvcs => {
+        self.get_pvcs().await;
+      }
+      IoEvent::GetPvs => {
+        self.get_pvs().await;
+      }
+      IoEvent::GetServiceAccounts => {
+        self.get_service_accounts().await;
+      }
     };
 
     let mut app = self.app.lock().await;
