@@ -39,6 +39,10 @@ static ROLES_TITLE: &str = "Roles";
 static ROLE_BINDINGS_TITLE: &str = "RoleBindings";
 static CLUSTER_ROLES_TITLE: &str = "ClusterRoles";
 static CLUSTER_ROLES_BINDING_TITLE: &str = "ClusterRoleBinding";
+static INGRESS_TITLE: &str = "Ingresses";
+static PVC_TITLE: &str = "PersistentVolumeClaims";
+static PV_TITLE: &str = "PersistentVolumes";
+static SVC_ACCT_TITLE: &str = "ServiceAccounts";
 static DESCRIBE_ACTIVE: &str = "-> Describe ";
 static YAML_ACTIVE: &str = "-> YAML ";
 
@@ -92,6 +96,10 @@ fn draw_more<B: Backend>(block: ActiveBlock, f: &mut Frame<'_, B>, app: &mut App
     ActiveBlock::RoleBindings => draw_role_bindings_tab(block, f, app, area),
     ActiveBlock::ClusterRoles => draw_cluster_roles_tab(block, f, app, area),
     ActiveBlock::ClusterRoleBinding => draw_cluster_role_binding_tab(block, f, app, area),
+    ActiveBlock::Ingress => draw_ingress_tab(block, f, app, area),
+    ActiveBlock::Pvc => draw_pvc_tab(block, f, app, area),
+    ActiveBlock::Pv => draw_pv_tab(block, f, app, area),
+    ActiveBlock::ServiceAccounts => draw_svc_acct_tab(block, f, app, area),
     ActiveBlock::Describe | ActiveBlock::Yaml => {
       let mut prev_route = app.get_prev_route();
       if prev_route.active_block == block {
@@ -106,6 +114,10 @@ fn draw_more<B: Backend>(block: ActiveBlock, f: &mut Frame<'_, B>, app: &mut App
         ActiveBlock::RoleBindings => draw_role_bindings_tab(block, f, app, area),
         ActiveBlock::ClusterRoles => draw_cluster_roles_tab(block, f, app, area),
         ActiveBlock::ClusterRoleBinding => draw_cluster_role_binding_tab(block, f, app, area),
+        ActiveBlock::Ingress => draw_ingress_tab(block, f, app, area),
+        ActiveBlock::Pvc => draw_pvc_tab(block, f, app, area),
+        ActiveBlock::Pv => draw_pv_tab(block, f, app, area),
+        ActiveBlock::ServiceAccounts => draw_svc_acct_tab(block, f, app, area),
         _ => { /* do nothing */ }
       }
     }
@@ -1025,6 +1037,61 @@ fn draw_storage_classes_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, a
   );
 }
 
+fn draw_svc_acct_tab<B: Backend>(
+  block: ActiveBlock,
+  f: &mut Frame<'_, B>,
+  app: &mut App,
+  area: Rect,
+) {
+  draw_resource_tab!(
+    SVC_ACCT_TITLE,
+    block,
+    f,
+    app,
+    area,
+    draw_svc_acct_tab,
+    draw_svc_acct_block,
+    app.data.service_accounts
+  );
+}
+
+fn draw_svc_acct_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
+  let title = get_resource_title(
+    app,
+    SVC_ACCT_TITLE,
+    "",
+    app.data.service_accounts.items.len(),
+  );
+
+  draw_resource_block(
+    f,
+    area,
+    ResourceTableProps {
+      title,
+      inline_help: DESCRIBE_YAML_AND_ESC_HINT.into(),
+      resource: &mut app.data.service_accounts,
+      table_headers: vec!["Namespace", "Name", "Secrets", "Age"],
+      column_widths: vec![
+        Constraint::Percentage(30),
+        Constraint::Percentage(30),
+        Constraint::Percentage(20),
+        Constraint::Percentage(20),
+      ],
+    },
+    |c| {
+      Row::new(vec![
+        Cell::from(c.namespace.to_owned()),
+        Cell::from(c.name.to_owned()),
+        Cell::from(c.secrets.to_string()),
+        Cell::from(c.age.to_owned()),
+      ])
+      .style(style_primary(app.light_theme))
+    },
+    app.light_theme,
+    app.is_loading,
+  );
+}
+
 fn draw_roles_tab<B: Backend>(block: ActiveBlock, f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
   draw_resource_tab!(
     ROLES_TITLE,
@@ -1185,7 +1252,7 @@ fn draw_cluster_role_binding_tab<B: Backend>(
     area,
     draw_cluster_role_binding_tab,
     draw_cluster_role_binding_block,
-    app.data.cluster_role_binding
+    app.data.cluster_role_bindings
   );
 }
 
@@ -1194,7 +1261,7 @@ fn draw_cluster_role_binding_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut A
     app,
     CLUSTER_ROLES_BINDING_TITLE,
     "",
-    app.data.cluster_role_binding.items.len(),
+    app.data.cluster_role_bindings.items.len(),
   );
 
   draw_resource_block(
@@ -1203,7 +1270,7 @@ fn draw_cluster_role_binding_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut A
     ResourceTableProps {
       title,
       inline_help: DESCRIBE_YAML_AND_ESC_HINT.into(),
-      resource: &mut app.data.cluster_role_binding,
+      resource: &mut app.data.cluster_role_bindings,
       table_headers: vec!["Name", "Role", "Age"],
       column_widths: vec![
         Constraint::Percentage(40),
@@ -1224,6 +1291,198 @@ fn draw_cluster_role_binding_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut A
   );
 }
 
+fn draw_ingress_tab<B: Backend>(
+  block: ActiveBlock,
+  f: &mut Frame<'_, B>,
+  app: &mut App,
+  area: Rect,
+) {
+  draw_resource_tab!(
+    INGRESS_TITLE,
+    block,
+    f,
+    app,
+    area,
+    draw_ingress_tab,
+    draw_ingress_block,
+    app.data.ingress
+  );
+}
+
+fn draw_ingress_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
+  let title = get_resource_title(app, INGRESS_TITLE, "", app.data.ingress.items.len());
+
+  draw_resource_block(
+    f,
+    area,
+    ResourceTableProps {
+      title,
+      inline_help: DESCRIBE_YAML_AND_ESC_HINT.into(),
+      resource: &mut app.data.ingress,
+      table_headers: vec![
+        "Namespace",
+        "Name",
+        "Ingress class",
+        "Paths",
+        "Default backend",
+        "Addresses",
+        "Age",
+      ],
+      column_widths: vec![
+        Constraint::Percentage(10),
+        Constraint::Percentage(20),
+        Constraint::Percentage(10),
+        Constraint::Percentage(25),
+        Constraint::Percentage(10),
+        Constraint::Percentage(10),
+        Constraint::Percentage(10),
+      ],
+    },
+    |c| {
+      Row::new(vec![
+        Cell::from(c.namespace.to_owned()),
+        Cell::from(c.name.to_owned()),
+        Cell::from(c.ingress_class.to_owned()),
+        Cell::from(c.paths.to_owned()),
+        Cell::from(c.default_backend.to_owned()),
+        Cell::from(c.address.to_owned()),
+        Cell::from(c.age.to_owned()),
+      ])
+      .style(style_primary(app.light_theme))
+    },
+    app.light_theme,
+    app.is_loading,
+  );
+}
+
+fn draw_pvc_tab<B: Backend>(block: ActiveBlock, f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
+  draw_resource_tab!(
+    PVC_TITLE,
+    block,
+    f,
+    app,
+    area,
+    draw_pvc_tab,
+    draw_pvc_block,
+    app.data.pvcs
+  );
+}
+
+fn draw_pvc_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
+  let title = get_resource_title(app, PVC_TITLE, "", app.data.pvcs.items.len());
+
+  draw_resource_block(
+    f,
+    area,
+    ResourceTableProps {
+      title,
+      inline_help: DESCRIBE_YAML_AND_ESC_HINT.into(),
+      resource: &mut app.data.pvcs,
+      table_headers: vec![
+        "Namespace",
+        "Name",
+        "Status",
+        "Volume",
+        "Capacity",
+        "Access Modes",
+        "Storage Class",
+        "Age",
+      ],
+      column_widths: vec![
+        Constraint::Percentage(10),
+        Constraint::Percentage(10),
+        Constraint::Percentage(10),
+        Constraint::Percentage(20),
+        Constraint::Percentage(10),
+        Constraint::Percentage(10),
+        Constraint::Percentage(10),
+        Constraint::Percentage(10),
+        Constraint::Percentage(10),
+      ],
+    },
+    |c| {
+      Row::new(vec![
+        Cell::from(c.namespace.to_owned()),
+        Cell::from(c.name.to_owned()),
+        Cell::from(c.status.to_owned()),
+        Cell::from(c.volume.to_owned()),
+        Cell::from(c.capacity.to_owned()),
+        Cell::from(c.access_modes.to_owned()),
+        Cell::from(c.storage_class.to_owned()),
+        Cell::from(c.age.to_owned()),
+      ])
+      .style(style_primary(app.light_theme))
+    },
+    app.light_theme,
+    app.is_loading,
+  );
+}
+
+fn draw_pv_tab<B: Backend>(block: ActiveBlock, f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
+  draw_resource_tab!(
+    PV_TITLE,
+    block,
+    f,
+    app,
+    area,
+    draw_pv_tab,
+    draw_pv_block,
+    app.data.pvs
+  );
+}
+
+fn draw_pv_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
+  let title = get_resource_title(app, PV_TITLE, "", app.data.pvs.items.len());
+
+  draw_resource_block(
+    f,
+    area,
+    ResourceTableProps {
+      title,
+      inline_help: DESCRIBE_YAML_AND_ESC_HINT.into(),
+      resource: &mut app.data.pvs,
+      table_headers: vec![
+        "Name",
+        "Capacity",
+        "Access Modes",
+        "Reclaim Policy",
+        "Status",
+        "Claim",
+        "Storage Class",
+        "Reason",
+        "Age",
+      ],
+      column_widths: vec![
+        Constraint::Percentage(20),
+        Constraint::Percentage(10),
+        Constraint::Percentage(10),
+        Constraint::Percentage(10),
+        Constraint::Percentage(10),
+        Constraint::Percentage(10),
+        Constraint::Percentage(10),
+        Constraint::Percentage(10),
+        Constraint::Percentage(10),
+      ],
+    },
+    |c| {
+      Row::new(vec![
+        Cell::from(c.name.to_owned()),
+        Cell::from(c.capacity.to_owned()),
+        Cell::from(c.access_modes.to_owned()),
+        Cell::from(c.reclaim_policy.to_owned()),
+        Cell::from(c.status.to_owned()),
+        Cell::from(c.claim.to_owned()),
+        Cell::from(c.storage_class.to_owned()),
+        Cell::from(c.reason.to_owned()),
+        Cell::from(c.age.to_owned()),
+      ])
+      .style(style_primary(app.light_theme))
+    },
+    app.light_theme,
+    app.is_loading,
+  );
+}
+
 /// common for all resources
 fn draw_describe_block<B: Backend>(
   f: &mut Frame<'_, B>,
